@@ -140,7 +140,7 @@ bool ntfs::check(Report& report, const QString& deviceNode) const
     return cmd.run(-1) && cmd.exitCode() == 0;
 }
 
-bool ntfs::create(Report& report, const QString& deviceNode) const
+bool ntfs::create(Report& report, const QString& deviceNode)
 {
     ExternalCommand cmd(report, QStringLiteral("mkfs.ntfs"), { QStringLiteral("--quick"), QStringLiteral("--verbose"), deviceNode });
     return cmd.run(-1) && cmd.exitCode() == 0;
@@ -179,7 +179,7 @@ bool ntfs::updateUUID(Report& report, const QString& deviceNode) const
 
 bool ntfs::updateBootSector(Report& report, const QString& deviceNode) const
 {
-    report.line() << xi18nc("@info/plain", "Updating boot sector for NTFS file system on partition <filename>%1</filename>.", deviceNode);
+    report.line() << xi18nc("@info:progress", "Updating boot sector for NTFS file system on partition <filename>%1</filename>.", deviceNode);
 
     quint32 n = firstSector();
     char* s = reinterpret_cast<char*>(&n);
@@ -191,21 +191,21 @@ bool ntfs::updateBootSector(Report& report, const QString& deviceNode) const
 
     QFile device(deviceNode);
     if (!device.open(QFile::ReadWrite | QFile::Unbuffered)) {
-        Log() << xi18nc("@info/plain", "Could not open partition <filename>%1</filename> for writing when trying to update the NTFS boot sector.", deviceNode);
+        Log() << xi18nc("@info:progress", "Could not open partition <filename>%1</filename> for writing when trying to update the NTFS boot sector.", deviceNode);
         return false;
     }
 
     if (!device.seek(0x1c)) {
-        Log() << xi18nc("@info/plain", "Could not seek to position 0x1c on partition <filename>%1</filename> when trying to update the NTFS boot sector.", deviceNode);
+        Log() << xi18nc("@info:progress", "Could not seek to position 0x1c on partition <filename>%1</filename> when trying to update the NTFS boot sector.", deviceNode);
         return false;
     }
 
     if (device.write(s, 4) != 4) {
-        Log() << xi18nc("@info/plain", "Could not write new start sector to partition <filename>%1</filename> when trying to update the NTFS boot sector.", deviceNode);
+        Log() << xi18nc("@info:progress", "Could not write new start sector to partition <filename>%1</filename> when trying to update the NTFS boot sector.", deviceNode);
         return false;
     }
 
-    Log() << xi18nc("@info/plain", "Updated NTFS boot sector for partition <filename>%1</filename> successfully.", deviceNode);
+    Log() << xi18nc("@info:progress", "Updated NTFS boot sector for partition <filename>%1</filename> successfully.", deviceNode);
 
     return true;
 }
